Page 70 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 70

Home

    "

    came to the Prophet Samuel and said, "... make us a
    king to judge us like all the nations" I Samuel 8:5. The
    rest of the story is recorded in I Samuel chapter eight:

    voice of the people in all that they say unto thee: for they
    have not rejected thee, but they have rejected me, that I
    should not reign over them.

    11 And he said, This will be the manner of the king
    that shall reign over you. He will take your sons, and
    appoint them for himself, for his chariots, and to be his
    horsemen; and some shall run before his chariots.

    12 And he will appoint him captains over thousands,
    and captains over fifties; and will set them to ear his
    ground, and to reap his harvest, and to make his
    instruments of war, and instruments of his chariots.

    13. And he will take your daughters to be
    confectioneries, and to be cooks, and to be bakers.

    14 And he will take your fields, and your vineyards,
    and your oliveyards, even the best of them, and give

    13

    15 And he will take the tenth of your seed, and of
    your vineyards, and give to his officers, and to his

    servants.

    16 And he will take your menservants, and your
    maidservants, and your goodliest young men, and your
    asses, and put them to his work.

    17 He will take the tenth of your sheep: and ye shall

    14

    Unwilling to accept responsibility, the Israelites
    rejected the first of the Ten Commandments, "Thou shalt
    have none other gods before me" in the hope that a king

    65

    The American Republic

    "\.. make us a

    7 And the Lord said unto Samuel, Hearken unto the

    them to his servants.

    be his servants.